"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = exports.displayDateUTC = void 0;

var _antd = require("antd");

var _react = _interopRequireDefault(require("react"));

var _etherscanLogoCircle = require("./assets/images/logos/etherscan-logo-circle.svg");

var _attachment = _interopRequireDefault(require("./attachment.js"));

require("./evidence-card.css");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const truncateAddress = address => `${address.substring(0, 6)}...${address.substring(address.length - 4, address.length)}`;

const months = ["Jan", "Feb", "Mar", "Apr", "May", "June", "July", "Aug", "Sept", "Oct", "Nov", "Dec"];

const displayDateUTC = dateString => {
  const _date = new Date(dateString);

  const date = String(_date.getUTCDate()).replace(/\b(\d{1})\b/g, "0$1");

  const month = _date.getUTCMonth();

  const year = _date.getUTCFullYear();

  const hours = String(_date.getUTCHours()).replace(/\b(\d{1})\b/g, "0$1");
  const minutes = String(_date.getUTCMinutes()).replace(/\b(\d{1})\b/g, "0$1");
  return `${date} ${months[month]} ${year} ${hours}:${minutes} UTC`;
};

exports.displayDateUTC = displayDateUTC;

class EvidenceCard extends _react.default.Component {
  render() {
    const {
      evidence,
      metaEvidence
    } = this.props;
    const submittedAtDate = new Date(evidence.submittedAt * 1000);
    return _react.default.createElement(_antd.Card, {
      style: {
        background: "white",
        borderRadius: "12px",
        boxShadow: "0px 6px 36px #bc9cff"
      },
      extra: _react.default.createElement("a", {
        href: `https://etherscan.com/address/${evidence.submittedBy}`
      }, _react.default.createElement(_etherscanLogoCircle.ReactComponent, {
        style: {
          width: "2rem",
          height: "auto"
        }
      })),
      title: _react.default.createElement("div", {
        style: {
          color: "#4d00b4"
        }
      }, evidence.evidenceJSON.title || evidence.evidenceJSON.name)
    }, _react.default.createElement("div", {
      style: {
        color: "black",
        padding: "1.5rem"
      }
    }, evidence.evidenceJSON.description), _react.default.createElement("div", {
      style: {
        background: "#f5f1fd",
        borderBottomLeftRadius: "12px",
        borderBottomRightRadius: "12px"
      }
    }, _react.default.createElement("div", {
      style: {
        padding: "1.5rem",
        borderBottomLeftRadius: "12px",
        borderBottomRightRadius: "12px"
      }
    }, _react.default.createElement(_antd.Row, null, _react.default.createElement(_antd.Col, {
      lg: 23
    }, _react.default.createElement("div", {
      style: {
        color: "#4d00b4",
        fontWeight: "500"
      }
    }, "Submitted By:", " ", metaEvidence.aliases && metaEvidence.aliases[evidence.submittedBy] ? metaEvidence.aliases[evidence.submittedBy] : truncateAddress(evidence.submittedBy), _react.default.createElement("div", {
      style: {
        fontWeight: "400"
      }
    }, displayDateUTC(submittedAtDate)))), _react.default.createElement(_antd.Col, {
      lg: 1
    }, _react.default.createElement(_attachment.default, {
      URI: evidence.evidenceJSON.fileURI,
      extension: evidence.evidenceJSON.fileTypeExtension
    }))))));
  }

}

var _default = EvidenceCard;
exports.default = _default;